==> myth-template-component-0.2.13.tgz: package/template/webpack.config.js <==
const path = require("path");
const fs = require("fs");
const ENV = "production";
const { VueLoaderPlugin } = require("vue-loader");
const Util = require("./release/util");
const ComponentPlugin = require("myth-webpack-plugin-component");
const OptimizeCssAssetsPlugin = require("optimize-css-assets-webpack-plugin");

const webpackConfig = {
    mode: null,
    optimization: null,
    entry: null,
    output: {
        filename: "[name].js",
        chunkFilename: "[id].css",
        path: Util.dir("dist"),
    },
    watch: true,
    devtool: "inline-source-map",
    resolve: {
        extensions: [".js", ".vue", ".json", ".css", ".scss"],
        alias: {
            lib: path.resolve(__dirname, "src/lib"),
        },
    },
    externals: {
        vue: "Vue",
    },
    plugins: [
        new VueLoaderPlugin(),
        new OptimizeCssAssetsPlugin({
            assetNameRegExp: /\.optimize\.css$/g,
            cssProcessor: require("cssnano"),
            cssProcessorPluginOptions: {
                preset: ["default", { discardComments: { removeAll: true } }],
            },
            canPrint: true,
        }),
    ],
    module: {
        noParse: /Vue/,
        rules: [
            {
                test: /\.m?js$/,
                exclude: /(node_modules|bower_components)/,
                use: {
                    loader: "babel-loader",
                    options: {
                        presets: [
                            [
                                "@vue/app",
                                {
                                    modules: false,
                                    loose: false,
                                    useBuiltIns: "entry",
                                },
                            ],
                        ],
                        plugins: [
                            "@babel/plugin-proposal-object-rest-spread",
                            "@babel/plugin-transform-runtime",
                            [
                                "component",
                                {
                                    libraryName: "element-ui",
                                    libraryDirectory: "lib",
                                    styleLibraryName: "theme-chalk",
                                },
                                "element-ui",
                            ],
                        ],
                    },
                },
            },
            {
                test: /\.vue$/,
                loader: "vue-loader",
            },
            {
                test: /\.css$/,
                use: ["style-loader", "css-loader"],
            },
            {
                test: /\.scss$/,
                use: [
                    "style-loader",
                    "css-loader", // translates CSS into CommonJS
                    {
                        loader: "sass-loader",
                        options: {
                            implementation: require("sass"),
                        },
                    },
                ],
            },
            {
                test: /\.(png|jpe?g|gif|svg)(\?.*)?$/,
                loader: "url-loader",
                options: {
                    limit: 1000000,
                },
            },
            {
                test: /\.(woff2?|eot|ttf|otf)(\?.*)?$/,
                loader: "url-loader",
                options: {
                    name: "[name].[ext]",
                    publicPath: "fonts/",
                    outputPath: "fonts/",
                    limit: 1000000,
                },
            },
        ],
    },
    devServer: {
        open: true,
        watchContentBase: true,
        host: "127.0.0.1",
        contentBase: path.join(__dirname, "public"),
        index: "index.html",
        disableHostCheck: true,
        liveReload: true,
        before(app) {
            // 本地读取配置文件
            app.get("/components", function (req, res) {
                let result = { code: 10000, data: Util.components() };
                res.json(result);
            });
            app.get("/*.json", function (req, res) {
                let uri = req.path,
                    name = uri.substr(1, uri.length - 6);
                let sourceFile = path.resolve("./src/" + name + "/config.json");
                if (!fs.existsSync(sourceFile)) {
                    return res.json({ message: "404", file: sourceFile });
                }
                let configData = JSON.parse(fs.readFileSync(sourceFile));
                res.json(configData);
            });
        },
        watchOptions: {
            poll: true,
        },
    },
    output: {
        filename: "[name].js",
        path: null,
    },
};

module.exports = (env, argv) => {
    let mode = argv.mode,
        isProduction = mode === ENV;
    webpackConfig.entry = Util.entrys(isProduction);
    webpackConfig.mode = mode;
    webpackConfig.optimization = Util.optimization(mode);
    webpackConfig.output.path = path.resolve(__dirname, Util.dir(mode));
    if (isProduction) {
        webpackConfig.watch = false;
        delete webpackConfig.devServer;
    } else {
        webpackConfig.plugins.push(new ComponentPlugin());
        webpackConfig.watchOptions = {
            ignored: ["node_modules"],
            poll: 1000,
        };
    }
    return webpackConfig;
};

==> myth-template-component-0.2.23.tgz: package/template/webpack.config.js <==
const path = require("path");
const fs = require("fs");
const ENV = "production";
const { VueLoaderPlugin } = require("vue-loader");
const Util = require("./release/util");
const ComponentPlugin = require("myth-webpack-plugin-component");

const webpackConfig = {
    mode: null,
    optimization: null,
    entry: null,
    output: {
        filename: "[name].js",
        chunkFilename: "[id].css",
        path: Util.dir("dist"),
    },
    devtool: false,
    resolve: {
        extensions: [".js", ".vue", ".json", ".css", ".scss"],
        alias: {
            lib: path.resolve(__dirname, "src/lib"),
        },
    },
    externals: {
        vue: "Vue",
    },
    plugins: [new VueLoaderPlugin()],
    module: {
        noParse: /Vue/,
        rules: [
            {
                test: /\.m?js$/,
                exclude: /(node_modules|bower_components)/,
                use: {
                    loader: "babel-loader",
                    options: {
                        presets: [
                            [
                                "@vue/app",
                                {
                                    modules: false,
                                    loose: false,
                                    useBuiltIns: "entry",
                                },
                            ],
                        ],
                        plugins: [
                            "@vue/babel-plugin-jsx",
                            "@babel/plugin-proposal-object-rest-spread",
                            "@babel/plugin-transform-runtime",
                        ],
                    },
                },
            },
            {
                test: /\.vue$/,
                loader: "vue-loader",
            },
            {
                test: /\.css$/,
                use: ["style-loader", "css-loader"],
            },
            {
                test: /\.scss$/,
                use: [
                    "style-loader",
                    "css-loader", // translates CSS into CommonJS
                    {
                        loader: "sass-loader",
                        options: {
                            implementation: require("sass"),
                        },
                    },
                ],
            },
            {
                test: /\.(png|jpe?g|gif|svg)(\?.*)?$/,
                loader: "url-loader",
                options: {
                    limit: 1000000,
                },
            },
            {
                test: /\.(woff2?|eot|ttf|otf)(\?.*)?$/,
                loader: "url-loader",
                options: {
                    name: "[name].[ext]",
                    publicPath: "fonts/",
                    outputPath: "fonts/",
                    limit: 1000000,
                },
            },
        ],
    },
    devServer: {
        static: {
            directory: path.join(__dirname, "public"),
        },
        port: "auto",
        hot: true,
        open: true,
        host: "127.0.0.1",
        allowedHosts: "all",
        setupMiddlewares: (middlewares, devServer) => {
            if (!devServer) {
                throw new Error("webpack-dev-server is not defined");
            }
            const { app } = devServer;
            // 本地读取配置文件
            app.get("/components", function (req, res) {
                let result = { code: 10000, data: Util.components() };
                res.json(result);
            });
            app.get("/*.json", function (req, res) {
                let uri = req.path,
                    name = uri.substr(1, uri.length - 6);
                let sourceFile = path.resolve("./src/" + name + "/config.json");
                if (!fs.existsSync(sourceFile)) {
                    return res.json({ message: "404", file: sourceFile });
                }
                let configData = JSON.parse(fs.readFileSync(sourceFile));
                res.json(configData);
            });
            return middlewares;
        },
    },
    output: {
        filename: "[name].js",
        path: null,
    },
};

module.exports = (env, argv) => {
    let mode = argv.mode,
        isProduction = mode === ENV;
    webpackConfig.entry = Util.entrys(isProduction);
    webpackConfig.mode = mode;
    webpackConfig.optimization = Util.optimization(mode);
    webpackConfig.output.path = path.resolve(__dirname, Util.dir(mode));
    if (isProduction) {
        webpackConfig.watch = false;
        delete webpackConfig.devServer;
    } else {
        webpackConfig.plugins.push(new ComponentPlugin());
        webpackConfig.watchOptions = {
            ignored: ["node_modules"],
            poll: 1000,
        };
    }
    return webpackConfig;
};
